%define anolis_release 6
%global gettext_package FontForge

Name:           fontforge
Version:        20230101
Release: %{anolis_release}%{dist}
Summary:        Outline and bitmap font editor

License:        GPLv3+
URL:            http://fontforge.github.io/
Source0:        https://github.com/fontforge/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz

Requires:       xdg-utils
Requires:       autotrace
Requires:       hicolor-icon-theme

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  libpng-devel
BuildRequires:  giflib-devel
BuildRequires:  libxml2-devel
BuildRequires:  freetype-devel
BuildRequires:  desktop-file-utils
BuildRequires:  libuninameslist-devel
BuildRequires:  libXt-devel
BuildRequires:  xorg-x11-proto-devel
BuildRequires:  gettext
BuildRequires:  pango-devel
BuildRequires:  cairo-devel
BuildRequires:  libspiro-devel
BuildRequires:  python3-devel
BuildRequires:  readline-devel
BuildRequires:  libappstream-glib
BuildRequires:  woff2-devel
BuildRequires:  shared-mime-info
BuildRequires:  gtk3-devel
BuildRequires:  python3-sphinx
BuildRequires:  make

# https://github.com/fontforge/fontforge/commit/642d8a3db6d4bc0e70b429622fdf01ecb09c4c10
Patch1000: fix-build-error.patch
Patch1001: 1001-fix-CVE-2024-25082-and-CVE-2024-25081.patch

%py_provides python3-fontforge
%py_provides python3-psMat

%description
FontForge (former PfaEdit) is a font editor for outline and bitmap
fonts. It supports a range of font formats, including PostScript
(ASCII and binary Type 1, some Type 3 and Type 0), TrueType, OpenType
(Type2) and CID-keyed fonts.

%package devel
Summary: Development files for fontforge
Requires: %{name} = %{version}-%{release}
Requires: %{name}-doc = %{version}-%{release}

%description devel
This package includes the library files you will need to compile
applications against fontforge.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

# Remove tests that requires Internet access
sed -i '45d;82d;101d;126d' tests/CMakeLists.txt

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%cmake -DCMAKE_BUILD_TYPE=Release \
          -DENABLE_WOFF2=ON
%cmake_build

%install
%cmake_install

desktop-file-install \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications            \
  desktop/org.fontforge.FontForge.desktop

rm -f %{buildroot}%{_datadir}/doc/fontforge/{.buildinfo,.nojekyll}
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.appdata.xml

# Find translations
%find_lang %{gettext_package}

%generate_compatibility_deps

%check
pushd %{__cmake_builddir}
make check
popd

%files -f %{gettext_package}.lang
%license LICENSE COPYING.gplv3
%{_bindir}/*
%{_libdir}/lib*.so.*
%{_datadir}/applications/*FontForge.desktop
%{_datadir}/fontforge
%{_datadir}/icons/hicolor/*/apps/org.fontforge.FontForge*
%{_mandir}/man1/*.1*
%{_datadir}/mime/packages/fontforge.xml
%{_metainfodir}/org.fontforge.FontForge.appdata.xml
%{python3_sitearch}/fontforge.so
%{python3_sitearch}/psMat.so

%dir %{abidir}
%{abidir}/lib*.dump
%{abidir}/fontforge.dump
%{abidir}/psMat.dump
%{abidir}/*-option.list

%files devel
%{_libdir}/lib*.so

%files doc
%doc %{_pkgdocdir}
%doc AUTHORS README.md

%changelog
* Fri May 31 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 20230101-6
- fix CVE-2024-25081 and CVE-2024-25082

* Wed Apr 10 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 20230101-5
- Rebuild for Anolis OS

* Mon Apr  1 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 20230101-4
- fix build error for fontforge
- fix build error (wb-zh951434@alibaba-inc.com)

* Tue Mar 12 2024 Bo Ren <rb01097748@alibaba-inc.com> - 20230101-3
- Rebuild with python3.11

* Thu Dec 14 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 20230101-2
- rebuild

* Wed Mar 22 2023 Zhongling He <zhonglingh@linux.alibaba.com> - 20230101-1
- Init package from upstream
